AsyncRelayCommand<TIn> class abstract

A Command that executes asynchronously.

Inheritance
Implementers

Constructors

AsyncRelayCommand()

Properties

canExecute ValueNotifier<bool>
Determines whether execution is allowed.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isExecuting ValueNotifier<bool>
Determines whether the asynchronous execution is finished or not.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call([Object? parameter]) Future<void>
Executes this command.
override
execute([Object? parameter]) Future<void>
Internally executes this command.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

withoutParam(Future<void> execute()) AsyncRelayCommand<void>
Initializes a new instance of AsyncRelayCommand that does not need any parameter when executing.
override
withParam<TIn>(Future<void> execute(TIn)) AsyncRelayCommand<TIn>
Initializes a new instance of AsyncRelayCommand that needs a parameter TIn when executing.
override