call abstract method
Executes this command.
parameteris an optional value. It will depend on the type of command whether this will be handled or not.
Implementation
void call([Object? parameter]);
Executes this command.
parameter is an optional value. It will depend on the type of command whether this will be handled or not.void call([Object? parameter]);